@@ -12,8 +12,13 @@ qq{02/01/2005 11:56:10 | E | 26.davinci | user=carjert group=ccc jobname=junk.pb
 qq{02/01/2005 18:48:10 | Q | 41.davinci | queue=workq},
 qq{02/01/2005 18:48:10 | S | 41.davinci | user=carjert group=ccc jobname=madbench.pbs queue=workq ctime=1107312490 qtime=1107312490 etime=1107312490 start=1107312490 exec_host=davinci/0*4 Resource_List.mem=500mb Resource_List.ncpus=4 Resource_List.walltime=00:10:00 },
 qq{02/01/2005 18:48:11 | E | 41.davinci | user=carjert group=ccc jobname=madbench.pbs queue=workq ctime=1107312490 qtime=1107312490 etime=1107312490 start=1107312490 exec_host=davinci/0*4 Resource_List.mem=500mb Resource_List.ncpus=4 Resource_List.walltime=00:10:00 session=19337 end=1107312491 Exit_status=255 resources_used.cpupercent=0 resources_used.cput=00:00:00 resources_used.mem=2352kb resources_used.ncpus=4 resources_used.vmem=8272kb resources_used.walltime=00:00:01},
+qq{10/04/2010 17:20:46 | E | 209367.cvrsvc09-ib | user=nonac group=nonac account=cstaff jobname=IOR queue=mag_serial ctime=1286238023 qtime=1286238023 etime=1286238023 start=1286238045 owner=nonac\@cvrsvc02-ib exec_host=c0935-ib/0 Resource_List.neednodes=1:ppn=2 Resource_List.nodect=1 Resource_List.nodes=1:ppn=2 Resource_List.walltime=00:10:00 session=13052 end=1286238046 Exit_status=1 resources_used.cput=00:00:00 resources_used.mem=0kb resources_used.vmem=0kb resources_used.walltime=00:00:02},
+qq{10/04/2010 17:23:24 | E | 209385.cvrsvc09-ib | user=nonac group=nonac account=cstaff jobname=IOR queue=mag_serial ctime=1286238184 qtime=1286238184 etime=1286238184 start=1286238203 owner=nonac\@cvrsvc02-ib exec_host=c0933-ib/0 Resource_List.neednodes=1:ppn=1 Resource_List.nodect=1 Resource_List.nodes=1:ppn=1 Resource_List.walltime=00:10:00 session=27544 end=1286238204 Exit_status=0 resources_used.cput=00:00:00 resources_used.mem=0kb resources_used.vmem=0kb resources_used.walltime=00:00:01},
 );
-@count = (0,1,5,12,13,17,24,25,29,36,37,41,-1);
+@count = (0,1,5,12,13,17,24,25,29,36,37,41,48,55,-1);
+@S_cnt = qw{1 4 7 10};
+@E_cnt = qw{2 5 8 11 12 13};
+@SE_cnt = qw{1 2 4 5 7 8 10 11 12 13};
 @records = (
 q{02/01/2005 10:23:18;Q;19.davinci;queue=workq},
 q{02/01/2005 10:23:18;S;19.davinci;user=gonwat group=mpccc jobname=n queue=workq ctime=1107282198 qtime=1107282198 etime=1107282198 start=1107282198 exec_host=davinci/0*4 Resource_List.mem=500mb Resource_List.ncpus=4 Resource_List.walltime=00:25:00 },
@@ -26,4 +31,6 @@ q{02/01/2005 11:56:10;S;26.davinci;user=carjert group=ccc jobname=junk.pbs queue
 q{02/01/2005 11:56:10;E;26.davinci;user=carjert group=ccc jobname=junk.pbs queue=workq ctime=1107287769 qtime=1107287769 etime=1107287769 start=1107287770 exec_host=davinci/0*4 Resource_List.mem=500mb Resource_List.ncpus=4 Resource_List.walltime=00:25:00 session=16607 end=1107287770 Exit_status=0 resources_used.cpupercent=0 resources_used.cput=00:00:00 resources_used.mem=4864kb resources_used.ncpus=4 resources_used.vmem=17600kb resources_used.walltime=00:00:00},
 q{02/01/2005 18:48:10;Q;41.davinci;queue=workq},
 q{02/01/2005 18:48:10;S;41.davinci;user=carjert group=ccc jobname=madbench.pbs queue=workq ctime=1107312490 qtime=1107312490 etime=1107312490 start=1107312490 exec_host=davinci/0*4 Resource_List.mem=500mb Resource_List.ncpus=4 Resource_List.walltime=00:10:00 },
-q{02/01/2005 18:48:11;E;41.davinci;user=carjert group=ccc jobname=madbench.pbs queue=workq ctime=1107312490 qtime=1107312490 etime=1107312490 start=1107312490 exec_host=davinci/0*4 Resource_List.mem=500mb Resource_List.ncpus=4 Resource_List.walltime=00:10:00 session=19337 end=1107312491 Exit_status=255 resources_used.cpupercent=0 resources_used.cput=00:00:00 resources_used.mem=2352kb resources_used.ncpus=4 resources_used.vmem=8272kb resources_used.walltime=00:00:01});
+q{02/01/2005 18:48:11;E;41.davinci;user=carjert group=ccc jobname=madbench.pbs queue=workq ctime=1107312490 qtime=1107312490 etime=1107312490 start=1107312490 exec_host=davinci/0*4 Resource_List.mem=500mb Resource_List.ncpus=4 Resource_List.walltime=00:10:00 session=19337 end=1107312491 Exit_status=255 resources_used.cpupercent=0 resources_used.cput=00:00:00 resources_used.mem=2352kb resources_used.ncpus=4 resources_used.vmem=8272kb resources_used.walltime=00:00:01},
+q{10/04/2010 17:20:46;E;209367.cvrsvc09-ib;user=nonac group=nonac account=cstaff jobname=IOR queue=mag_serial ctime=1286238023 qtime=1286238023 etime=1286238023 start=1286238045 owner=nonac@cvrsvc02-ib exec_host=c0935-ib/0 Resource_List.neednodes=1:ppn=2 Resource_List.nodect=1 Resource_List.nodes=1:ppn=2 Resource_List.walltime=00:10:00 session=13052 end=1286238046 Exit_status=1 resources_used.cput=00:00:00 resources_used.mem=0kb resources_used.vmem=0kb resources_used.walltime=00:00:02},
+q{10/04/2010 17:23:24;E;209385.cvrsvc09-ib;user=nonac group=nonac account=cstaff jobname=IOR queue=mag_serial ctime=1286238184 qtime=1286238184 etime=1286238184 start=1286238203 owner=nonac@cvrsvc02-ib exec_host=c0933-ib/0 Resource_List.neednodes=1:ppn=1 Resource_List.nodect=1 Resource_List.nodes=1:ppn=1 Resource_List.walltime=00:10:00 session=27544 end=1286238204 Exit_status=0 resources_used.cput=00:00:00 resources_used.mem=0kb resources_used.vmem=0kb resources_used.walltime=00:00:01},);
